==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/ObjectHandler.h <==
// public class gnu.java.beans.decoder.ObjectHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class 44f4ffe2dca613a5 gnu_java_beans_decoder_ObjectHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractElementHandler

#include "gnu/java/beans/decoder/AbstractElementHandler.h"

#ifndef _JC_gnu_java_beans_decoder_ObjectHandler_H_
#define _JC_gnu_java_beans_decoder_ObjectHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_beans_ExceptionListener$object;
struct _jc_java_lang_Class$object;
struct _jc_org_xml_sax_Attributes$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_ObjectHandler$sub_refs	_jc_gnu_java_beans_decoder_ObjectHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_ObjectHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_ObjectHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ObjectHandler$refs	_jc_gnu_java_beans_decoder_ObjectHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_ObjectHandler$nonrefs	_jc_gnu_java_beans_decoder_ObjectHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ObjectHandler$object	_jc_gnu_java_beans_decoder_ObjectHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_ObjectHandler$vmethods	_jc_gnu_java_beans_decoder_ObjectHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_ObjectHandler$vtable	_jc_gnu_java_beans_decoder_ObjectHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_ObjectHandler$vtype	_jc_gnu_java_beans_decoder_ObjectHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_ObjectHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectHandler$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_java_beans_decoder_ObjectHandler$method$startElement$c132d696183c1bce(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectHandler$object *, struct _jc_object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_ObjectHandler$method_info$startElement$c132d696183c1bce;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_ObjectHandler$vmethods {
	struct _jc_object	*(*startElement$c132d696183c1bce)(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectHandler$object *, struct _jc_object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_ObjectHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_ObjectHandler$vmethods	gnu_java_beans_decoder_ObjectHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_ObjectHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_ObjectHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ObjectHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ObjectHandler$refs {
    _jc_gnu_java_beans_decoder_ObjectHandler$sub_refs	gnu_java_beans_decoder_ObjectHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ObjectHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ObjectHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_ObjectHandler$sub_nonrefs	gnu_java_beans_decoder_ObjectHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_ObjectHandler$object {
	_jc_gnu_java_beans_decoder_ObjectHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_ObjectHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_ObjectHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_ObjectHandler$vtype _jc_gnu_java_beans_decoder_ObjectHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_ObjectHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_ObjectHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_ObjectHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/ObjectHandler.h <==
// public class gnu.java.beans.decoder.ObjectHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class 44f4ffe2dca613a5 gnu_java_beans_decoder_ObjectHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractElementHandler

#include "gnu/java/beans/decoder/AbstractElementHandler.h"

#ifndef _JC_gnu_java_beans_decoder_ObjectHandler_H_
#define _JC_gnu_java_beans_decoder_ObjectHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_beans_ExceptionListener$object;
struct _jc_java_lang_Class$object;
struct _jc_org_xml_sax_Attributes$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_ObjectHandler$sub_refs	_jc_gnu_java_beans_decoder_ObjectHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_ObjectHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_ObjectHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ObjectHandler$refs	_jc_gnu_java_beans_decoder_ObjectHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_ObjectHandler$nonrefs	_jc_gnu_java_beans_decoder_ObjectHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ObjectHandler$object	_jc_gnu_java_beans_decoder_ObjectHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_ObjectHandler$vmethods	_jc_gnu_java_beans_decoder_ObjectHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_ObjectHandler$vtable	_jc_gnu_java_beans_decoder_ObjectHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_ObjectHandler$vtype	_jc_gnu_java_beans_decoder_ObjectHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_ObjectHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_java_beans_decoder_ObjectHandler$method$startElement$c132d696183c1bce(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectHandler$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_ObjectHandler$method_info$startElement$c132d696183c1bce;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_ObjectHandler$vmethods {
	struct _jc_object	*(*startElement$c132d696183c1bce)(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectHandler$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_ObjectHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_ObjectHandler$vmethods	gnu_java_beans_decoder_ObjectHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_ObjectHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_ObjectHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ObjectHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ObjectHandler$refs {
    _jc_gnu_java_beans_decoder_ObjectHandler$sub_refs	gnu_java_beans_decoder_ObjectHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ObjectHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ObjectHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_ObjectHandler$sub_nonrefs	gnu_java_beans_decoder_ObjectHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_ObjectHandler$object {
	_jc_gnu_java_beans_decoder_ObjectHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_ObjectHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_ObjectHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_ObjectHandler$vtype _jc_gnu_java_beans_decoder_ObjectHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_ObjectHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_ObjectHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_ObjectHandler_H_ */
